import React from 'react';
import { withRouter, Link } from "react-router-dom";
import { getFilteredProducts } from '../actions/apiRequests';
import "./../styles/Search.css";

class Search extends React.Component {
    constructor(props){
        super(props);
        this.state = {
            searchTerm: '',
            searchBy: 'name',
            results: [],
        };

        this.submit = this.submit.bind(this);
        this.changeTerm = this.changeTerm.bind(this);
        this.handleRadioButton = this.handleRadioButton.bind(this);
    }

    changeTerm(event) {
        this.setState({searchTerm: event.target.value});
    }

    handleRadioButton(value) {
        this.setState({
            searchBy: value
        });
      }

    async submit(event){
        event.preventDefault();
        const data = await getFilteredProducts(this.state.searchTerm, this.state.searchBy)
            .then(res => {
                this.setState({results: res});
            })
            .catch(err => console.log(err));

        if(this.props.location.pathname === "/searchResults"){
            this.props.history.push("/products", this.state);
        }
        
        this.props.history.push("/searchResults", this.state);
    }

    //Need to search by name or SKU
    render(){
        return (
            <div>
                <form className="d-flex" onSubmit={this.submit}>
                    <input
                    type="search"
                    className="form-control me-2"
                    placeholder="Search for item..."
                    onChange={event => this.changeTerm(event)}
                    />
                    <div className="form-check form-check-inline">
                        <input className="form-check-input" type="radio" name="inlineRadioOptions" checked={this.state.searchBy === "name"} onChange={() => this.handleRadioButton("name")} id="searchByName" value="name" />
                        <label className="form-check-label" htmlFor="searchByName">Name</label>
                    </div>
                    <div className="form-check form-check-inline">
                        <input className="form-check-input" type="radio" name="inlineRadioOptions" checked={this.state.searchBy === "sku"} onChange={() => this.handleRadioButton("sku")} id="searchBySku" value="sku" />
                        <label className="form-check-label" htmlFor="searchBySKU">Sku</label>
                    </div>
                    <button className="btn btn-primary" type="submit">
                        GO
                    </button>
                </form>
                    <Link to={{
                    pathname: '/searchResults',
                    state: {results: this.state.results}
                }} />
            </div>
          );
    }
}

export default withRouter(Search);