import { useState, useEffect } from "react";
import { useForm } from "react-hook-form";
import "./promoStyle.css";
import { NavLink } from 'react-router-dom';
import Config from '../../config';
import { useHistory } from 'react-router'
import { Dropdown } from 'semantic-ui-react'
import {getAllProducts} from '../../actions/apiRequests'


export default function PromotionNewFormComponent (props) {
    const { register, handleSubmit, setValue, formState: { errors } } = useForm();
    const history = useHistory();
    const [serverErrors, setErrors] = useState([]);
    const [productData, setproductData] = useState([]);


    const onSubmit = (data) => {
        console.log(data)

        fetch(`${Config.promotionsUrl}`, {
            method: "POST",
            headers: {
                "Content-Type": "application/json",
            },
            body: JSON.stringify(data),
            })
            .then(res => res.ok ? history.push("/promos") : setErrors(["There is already an existing Promotion Id"]))
            .catch(err => setErrors([err.message]))
    };


    useEffect(() => {
        loadProducts();
    }, [])

    const loadProducts = async (event) => {
        const data = await getAllProducts();

        setproductData(data);

    }

    const onChange = (e, data) => {
        console.log(data)
        setValue('productSku', data.value)
        console.log(productSku)
    }


    const productSku = register('productSku', { required: true })

    return (
        <div>
            <div className="promo-container">
                <div className="promo-form-container">
                    <h1 className="promo-form-title">Add Promotion</h1>

                <form className="promo-form" onSubmit={handleSubmit(onSubmit)}>
                        {serverErrors.length ? <p className="form-error">{serverErrors}</p> : ""}

                <div className="form-group">
                    <label>Promotion Id</label>
                    <input
                        {...register("promotionId", {
                            required: "promotion id is required",
                            maxLength: { value: 10, message: "You exceeded the maximum value" }
                        })}
                        id="promotionId"
                        className="form-control"
                                placeholder="eg. PROMO-403"
                    />

                            {errors.promotionId && <p className="form-error">{errors.promotionId.message}</p>}

                </div>

                <div className="form-group">
                    <label>Product Sku</label>
                    {/* <input
                        {...register("productSku", {
                            required: "product sku required",
                            maxLength: { value: 10, message: "You exceeded the maximum value" }
                        })}
                        id="productSku"
                        className="form-control"
                                placeholder="eg. SKU-39SD"
                    /> */}
                            <Dropdown
                                placeholder='Select Product'
                                fluid
                                search
                                selection
                                onChange={onChange}
                                onSearchChange={onChange}
                                options={productData.map(prod => {
                                    return {
                                        key: prod.sku,
                                        text: prod.sku,
                                        value: prod.sku,
                                    }
                                })}
                                    />
                            {errors.productSku && <p className="form-error">{errors.productSku.message}</p>}
                    <br></br>
                </div>

                <div className="form-group">
                    <label>Enter % off</label>
                    <div className="input-group">

                            <div className="input-group-prepend">
                    <span className="input-group-text">%</span></div>
                    <input
                        {...register("discountPercentage", {
                            valueAsNumber: true,
                            required: "% off required",
                            min: { value: 0, message: "% must be greater than or equal to 0" },
                            max: { value: 100, message: "% must be less than or equal to 100" },
                        })}
                        id="discountPercentage"
                        className="form-control"
                                placeholder="20"
                                type="number"
                    />
                            </div>
                        {errors.discountPercentage && <p className="form-error">{errors.discountPercentage.message}</p>}

                </div>

                <div className="form-group">
                    <label>Applies at Minimum Quantity</label>
                    <input
                        {...register("minimumQuantity", {
                            valueAsNumber: true,
                            required: "minimum quantity is required",
                            min: { value: 1, message: "discount percentage must be greater than 0" },

                        })}
                        id="minimumQuantity"
                        className="form-control"
                        type="number"
                        min="1"
                        placeholder="1"
                    />
                            {errors.minimumQuantity && <p className="form-error">{errors.minimumQuantity.message}</p>}
                    </div>
                        <input className="promo-submit" type="submit" value="Save Promotion" />
                        <NavLink className="promo-cancel" to="/promos">Cancel</NavLink>
            </form>
                </div>
            </div>
        </div>
    );
}
